#include "ZepicsBD.h"
      implicit none
#include "Zmedia.h"
#include "Zptcl.h"
#include "Zcode.h"
c
c                      Creating brems sampling table
c
      record /epmedia/media

      integer::icon, how
      character(100)::file
      read(*, '(i2, a)')  how, file
      if( how < -1 .or. how >1 )  then
         write(0,*) ' how=',how, ' is wrong'
         stop
      endif

c      write(0,*) ' entering epBPgeneini'
      call epBPgeneini(file, media, how)
c      write(0,*) ' entering epExpot'
      call epExpot(media)
c           next 1.d-4 is dummy; this is to compute 
c           Sternheimer's consts and to put them in the table
c      write(0,*) ' entering epStern'
      call epStern(1.d-4, media)
c      write(0,*) ' entering epSetPhotoE'
      call epSetPhotoE(media, media.pe)  ! this is also not essential ?
                                         ! to create sampling talbe
                                         ! but for putting consts in the table

c      write(0,*) ' entering epwtmedia'
      call epwtmedia(media)  ! this writes some basic data
c                            ! must be skipped when reading

      call epDisableLPM
c             Brems table by Seltzer data region
c      write(0,*) ' entering epCreBrSTblS'
      call epCreBrSTblS(media, media.cnst)

c         GeV region upto complete screening
c      write(0,*) ' entering epCreBrSTbl'
      call epCreBrSTbl1(media, media.cnst)

c      LPM   from EeminLPM 
      call epAbleLPM
c       
c      write(0,*) ' entering epCreBrSTbH'
      call epCreBrSTbH(media, media.cnst)
      end
      subroutine  epDisableLPM
      implicit none
#include "ZepTrackp.h"
      LPMeffect=.false.
      Flpm= 1.0
      end
      subroutine  epAbleLPM
      implicit none
#include "ZepTrackp.h"
      LPMeffect=.true.
      Flpm= 1.0
      end
